@@ -1,7 +1,7 @@
 import argparse
 import logging
 
-from visionaire4 import export, restore
+from visionaire4 import export, restore, report
 
 
 class VersionAction(argparse.Action):
@@ -55,6 +55,7 @@ def get_main_parser():
 
     export.add_parser(subparser, parent_parser)
     restore.add_parser(subparser, parent_parser)
+    report.add_parser(subparser, parent_parser)
     return parser
 
 
