@@ -3,5 +3,5 @@ from .generator import (
     gen_compose_config,
     gen_grafana_dashboard_cfg,
     gen_grafana_datasource_cfg,
-    gen_grafana_dashboards
-)
\ No newline at end of file
+    gen_grafana_dashboards,
+)
