@@ -9,7 +9,7 @@ from docker.models.containers import Container
 from docker.errors import NotFound
 from datetime import datetime
 
-from visionaire4.utils import find_v4_container, find_prom_container
+from visionaire4.utils import find_v4_container, find_prom_container, fix_address
 
 EXPORT_TYPE = ["metrics", "edge"]
 V4_MIN_VERSION = 43301
@@ -35,18 +35,6 @@ def docker_copy_to_host(c: Container, src: str, dst: str, title=""):
         print("\bdone")
 
 
-def fix_address(addr: str, name: str) -> str:
-    split = addr.split(":")
-    if len(split) < 2:
-        raise ValueError(
-            f"address for '{name}' is not valid, expected format: "
-            f"'host:port', got: '{addr}'."
-        )
-    if "://" not in addr:
-        addr = "http://" + addr
-    return addr
-
-
 def get_v4_status(v4_addr: str) -> dict:
     resp = requests.get(v4_addr, timeout=5)
     if resp.status_code != 200:
@@ -212,7 +200,7 @@ def add_parser(subparser, parent_parser=None):
         type=str,
         default="localhost:4004",
         metavar="HOST:PORT",
-        help="Visionaire4 address. Default: 'localhost:4004'",
+        help="Visionaire4 address. Expected format 'host:port'. Default: 'localhost:4004'",
     )
     parser.add_argument(
         "--v4-name",
